@@ -16,7 +16,7 @@
 #ifndef RADIUSD_H
 #define RADIUSD_H
 /**
- * $Id: c3e8cdd142ad2b74729e92b9b907afe3f545b578 $
+ * $Id: 982f2124c62f8309bddfbebb2c5f57f6734fd5f0 $
  *
  * @file radiusd.h
  * @brief Structures, prototypes and global variables for the FreeRADIUS server.
@@ -24,7 +24,7 @@
  * @copyright 1999-2000,2002-2008  The FreeRADIUS server project
  */
 
-RCSIDH(radiusd_h, "$Id: c3e8cdd142ad2b74729e92b9b907afe3f545b578 $")
+RCSIDH(radiusd_h, "$Id: 982f2124c62f8309bddfbebb2c5f57f6734fd5f0 $")
 
 #include <freeradius/libradius.h>
 #include <freeradius/radpaths.h>
@@ -141,6 +141,8 @@ typedef struct main_config {
 	uint32_t	cleanup_delay;			//!< How long before cleaning up cached responses.
 	uint32_t	max_requests;
 
+	uint32_t       	proxy_dedup_window;		//!< suppress duplicate retransmitssions from a NAS
+
 	bool		postauth_client_lost;		//!< Whether to run Post-Auth-Type Client-Lost section
 
 	uint32_t	debug_level;
@@ -357,8 +359,8 @@ extern char const	*radacct_dir;
 extern char const	*radlog_dir;
 extern char const	*radlib_dir;
 extern bool		log_stripped_names;
-extern char const	*radiusd_version;
-extern char const	*radiusd_version_short;
+extern HIDDEN char const	*radiusd_version;
+extern HIDDEN char const	*radiusd_version_short;
 void			radius_signal_self(int flag);
 
 typedef enum {
@@ -380,9 +382,9 @@ int		rad_accounting(REQUEST *);
 int		rad_coa_recv(REQUEST *request);
 
 /* session.c */
-int		rad_check_ts(fr_ipaddr_t const *nas_addr, uint32_t nas_port, char const *user, char const *sessionid);
+int		rad_check_ts(fr_ipaddr_t const *nas_addr, uint32_t nas_port, char const *nas_port_id, char const *user, char const *sessionid);
 int		session_zap(REQUEST *request, fr_ipaddr_t const *nas_addr,
-			    uint32_t nas_port, char const *user,
+			    uint32_t nas_port, char const *nas_port_id, char const *user,
 			    char const *sessionid, uint32_t cliaddr,
 			    char proto, int session_time);
 
@@ -545,6 +547,7 @@ int	total_active_threads(void);
 void	thread_pool_lock(void);
 void	thread_pool_unlock(void);
 void	thread_pool_queue_stats(int array[RAD_LISTEN_MAX], int pps[2]);
+void	thread_pool_thread_stats(int stats[3]);
 
 #ifndef HAVE_PTHREAD_H
 #  define rad_fork(n) fork()
